<?php

namespace Beo\Career\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Database\RequestScope;
use Beo\Career\Forms\Remark as RemarkForm;
use Beo\Career\Http\Requests\RemarkRequest;
use Beo\Career\Http\Resources\RemarkResource;
use Beo\Career\Http\Resources\RemarksCollection;
use Beo\Career\Models\Remark;
use Beo\Career\Scopes\RemarkResourceScope;


/**
 * Resource controller class for remark.
 */
class RemarkResourceController extends BaseController
{

    /**
     * Initialize remark resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->form = RemarkForm::grouped(false)
                        ->setAttributes()
                        ->toArray();
        $this->modules = $this->modules(config('beo.career.modules'), 'career', guard_url('career'));
    }

    /**
     * Display a list of remark.
     *
     * @return Response
     */
    public function index(RemarkRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Remark::pushScope(new RequestScope())
            ->pushScope(new RemarkResourceScope())
            ->simplePaginate($pageLimit);

        $data = new RemarksCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('career::remark.names'))
            ->view('career::remark.index')
            ->data(compact('data', 'modules', 'form'));
    }

    /**
     * Display remark.
     *
     * @param Request $request
     * @param Model   $remark
     *
     * @return Response
     */
    public function show(RemarkRequest $request, Remark $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new RemarkResource($model);

        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('career::remark.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('career::remark.show');
    }

    /**
     * Show the form for creating a new remark.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(RemarkRequest $request, Remark $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new RemarkResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('career::remark.name'))
            ->view('career::remark.create')
            ->data(compact('data', 'form', 'modules'));
    }

    /**
     * Create new remark.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(RemarkRequest $request, Remark $model)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $model->create($attributes);
            $data = new RemarkResource($model);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('career::remark.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('career/remark/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/career/remark'))
                ->redirect();
        }

    }

    /**
     * Show remark for editing.
     *
     * @param Request $request
     * @param Model   $remark
     *
     * @return Response
     */
    public function edit(RemarkRequest $request, Remark $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new RemarkResource($model);

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('career::remark.name'))
            ->view('career::remark.edit')
            ->data(compact('data', 'form', 'modules'));
    }

    /**
     * Update the remark.
     *
     * @param Request $request
     * @param Model   $remark
     *
     * @return Response
     */
    public function update(RemarkRequest $request, Remark $model)
    {
        try {
            $attributes = $request->all();
            $model->update($attributes);
            $data = new RemarkResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('career::remark.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('career/remark/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('career/remark/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the remark.
     *
     * @param Model   $remark
     *
     * @return Response
     */
    public function destroy(RemarkRequest $request, Remark $model)
    {
        try {
            $model->delete();
            $data = new RemarkResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('career::remark.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('career/remark/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('career/remark/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
